@@ -1,7 +1,9 @@
+import asyncio
 import logging
 import threading
 import time
 
+from abc import ABC, abstractmethod
 from functools import wraps
 from typing import Optional
 
@@ -19,12 +21,12 @@ def action(f):
         result = f(*args, **kwargs)
 
         if result and isinstance(result, Response):
-            result.errors = result.errors \
-                if isinstance(result.errors, list) else [result.errors]
+            result.errors = (
+                result.errors if isinstance(result.errors, list) else [result.errors]
+            )
             response = result
         elif isinstance(result, tuple) and len(result) == 2:
-            response.errors = result[1] \
-                if isinstance(result[1], list) else [result[1]]
+            response.errors = result[1] if isinstance(result[1], list) else [result[1]]
 
             if len(response.errors) == 1 and response.errors[0] is None:
                 response.errors = []
@@ -39,12 +41,14 @@ def action(f):
     return _execute_action
 
 
-class Plugin(EventGenerator, ExtensionWithManifest):   # lgtm [py/missing-call-to-init]
-    """ Base plugin class """
+class Plugin(EventGenerator, ExtensionWithManifest):  # lgtm [py/missing-call-to-init]
+    """Base plugin class"""
 
     def __init__(self, **kwargs):
         super().__init__()
-        self.logger = logging.getLogger('platypush:plugin:' + get_plugin_name_by_class(self.__class__))
+        self.logger = logging.getLogger(
+            'platypush:plugin:' + get_plugin_name_by_class(self.__class__)
+        )
         if 'logging' in kwargs:
             self.logger.setLevel(getattr(logging, kwargs['logging'].upper()))
 
@@ -53,8 +57,9 @@ class Plugin(EventGenerator, ExtensionWithManifest):   # lgtm [py/missing-call-t
         )
 
     def run(self, method, *args, **kwargs):
-        assert method in self.registered_actions, '{} is not a registered action on {}'.\
-            format(method, self.__class__.__name__)
+        assert (
+            method in self.registered_actions
+        ), '{} is not a registered action on {}'.format(method, self.__class__.__name__)
         return getattr(self, method)(*args, **kwargs)
 
 
@@ -62,6 +67,7 @@ class RunnablePlugin(Plugin):
     """
     Class for runnable plugins - i.e. plugins that have a start/stop method and can be started.
     """
+
     def __init__(self, poll_interval: Optional[float] = None, **kwargs):
         """
         :param poll_interval: How often the :meth:`.loop` function should be execute (default: None, no pause/interval).
@@ -78,6 +84,9 @@ class RunnablePlugin(Plugin):
     def should_stop(self):
         return self._should_stop.is_set()
 
+    def wait_stop(self, timeout=None):
+        return self._should_stop.wait(timeout=timeout)
+
     def start(self):
         set_thread_name(self.__class__.__name__)
         self._thread = threading.Thread(target=self._runner)
@@ -110,4 +119,74 @@ class RunnablePlugin(Plugin):
         self._thread = None
 
 
+class AsyncRunnablePlugin(RunnablePlugin, ABC):
+    """
+    Class for runnable plugins with an asynchronous event loop attached.
+    """
+
+    def __init__(self, *args, _stop_timeout: Optional[float] = 30.0, **kwargs):
+        super().__init__(*args, **kwargs)
+
+        self._stop_timeout = _stop_timeout
+        self._loop: Optional[asyncio.AbstractEventLoop] = None
+        self._loop_runner: Optional[threading.Thread] = None
+        self._task: Optional[asyncio.Task] = None
+
+    @property
+    def _should_start_runner(self):
+        return True
+
+    @abstractmethod
+    async def listen(self):
+        pass
+
+    async def _listen(self):
+        try:
+            await self.listen()
+        except KeyboardInterrupt:
+            pass
+        except RuntimeError as e:
+            if not (
+                str(e).startswith('Event loop stopped before ')
+                or str(e).startswith('no running event loop')
+            ):
+                raise e
+
+    def _start_listener(self):
+        set_thread_name(self.__class__.__name__ + ':listener')
+        self._loop = asyncio.new_event_loop()
+        asyncio.set_event_loop(self._loop)
+
+        self._task = self._loop.create_task(self._listen())
+        self._task.set_name(self.__class__.__name__ + '.listen')
+        self._loop.run_forever()
+
+    def main(self):
+        if self.should_stop() or (self._loop_runner and self._loop_runner.is_alive()):
+            self.logger.info('The main loop is already being run/stopped')
+            return
+
+        if self._should_start_runner:
+            self._loop_runner = threading.Thread(target=self._start_listener)
+            self._loop_runner.start()
+
+        self.wait_stop()
+
+    def stop(self):
+        if self._task and self._loop and not self._task.done():
+            self._loop.call_soon_threadsafe(self._task.cancel)
+
+        if self._loop and self._loop.is_running():
+            self._loop.call_soon_threadsafe(self._loop.stop)
+            self._loop = None
+
+        if self._loop_runner and self._loop_runner.is_alive():
+            try:
+                self._loop_runner.join(timeout=self._stop_timeout)
+            finally:
+                self._loop_runner = None
+
+        super().stop()
+
+
 # vim:sw=4:ts=4:et:
