@@ -1,17 +1,13 @@
 from typing import Any, Dict, Optional, List, Union
 
-from openzwave.group import ZWaveGroup
-from openzwave.node import ZWaveNode
-from openzwave.scene import ZWaveScene
-from openzwave.value import ZWaveValue
-
 from platypush.backend.zwave import ZwaveBackend
 from platypush.context import get_backend
 from platypush.plugins import action
 from platypush.plugins.switch import SwitchPlugin
+from platypush.plugins.zwave._base import ZwaveBasePlugin
 
 
-class ZwavePlugin(SwitchPlugin):
+class ZwavePlugin(ZwaveBasePlugin, SwitchPlugin):
     """
     This plugin interacts with the devices on a Z-Wave network started through the
     :class:`platypush.backend.zwave.ZwaveBackend` backend.
@@ -57,6 +53,7 @@ class ZwavePlugin(SwitchPlugin):
     def status(self) -> Dict[str, Any]:
         """
         Get the status of the controller.
+
         :return: dict
         """
         backend = self._get_backend()
@@ -151,12 +148,13 @@ class ZwavePlugin(SwitchPlugin):
         controller.request_node_neighbor_update(node.node_id)
 
     @staticmethod
-    def value_to_dict(value: Optional[ZWaveValue]) -> Dict[str, Any]:
+    def value_to_dict(value) -> Dict[str, Any]:
         if not value:
             return {}
 
         return {
-            'command_class': value.node.get_command_class_as_string(value.command_class) if value.command_class else None,
+            'command_class': value.node.get_command_class_as_string(value.command_class)
+            if value.command_class else None,
             'data': value.data,
             'data_as_string': value.data_as_string,
             'data_items': list(value.data_items) if isinstance(value.data_items, set) else value.data_items,
@@ -187,7 +185,7 @@ class ZwavePlugin(SwitchPlugin):
         }
 
     @staticmethod
-    def group_to_dict(group: Optional[ZWaveGroup]) -> Dict[str, Any]:
+    def group_to_dict(group) -> Dict[str, Any]:
         if not group:
             return {}
 
@@ -199,7 +197,7 @@ class ZwavePlugin(SwitchPlugin):
         }
 
     @classmethod
-    def node_to_dict(cls, node: Optional[ZWaveNode]) -> Dict[str, Any]:
+    def node_to_dict(cls, node) -> Dict[str, Any]:
         if not node:
             return {}
 
@@ -218,7 +216,8 @@ class ZwavePlugin(SwitchPlugin):
             'is_awake': node.is_awake if hasattr(node, 'is_awake') else False,
             'is_failed': node.is_failed if hasattr(node, 'is_failed') else False,
             'is_beaming_device': node.is_beaming_device if hasattr(node, 'is_beaming_device') else False,
-            'is_frequent_listening_device': node.is_frequent_listening_device if hasattr(node, 'is_frequent_listening_device') else False,
+            'is_frequent_listening_device': node.is_frequent_listening_device
+            if hasattr(node, 'is_frequent_listening_device') else False,
             'is_info_received': node.is_info_received if hasattr(node, 'is_info_received') else False,
             'is_listening_device': node.is_listening_device if hasattr(node, 'is_listening_device') else False,
             'is_locked': node.is_locked if hasattr(node, 'is_locked') else False,
@@ -256,7 +255,7 @@ class ZwavePlugin(SwitchPlugin):
             } if hasattr(node, 'values') else {},
         }
 
-    def _get_node(self, node_id: Optional[int] = None, node_name: Optional[str] = None) -> ZWaveNode:
+    def _get_node(self, node_id: Optional[int] = None, node_name: Optional[str] = None):
         assert node_id is not None or node_name is not None, 'Specify either node_id or name'
         nodes = self._get_backend().network.nodes
 
@@ -268,14 +267,14 @@ class ZwavePlugin(SwitchPlugin):
         assert nodes, 'No such node name: {}'.format(node_name)
         return nodes[0]
 
-    def _get_groups(self) -> Dict[int, ZWaveGroup]:
+    def _get_groups(self) -> dict:
         return {
             group_index: group
             for node in self._get_backend().network.nodes.values()
             for group_index, group in node.groups.items()
         }
 
-    def _get_group(self, group_index: Optional[int] = None, group_label: Optional[str] = None) -> ZWaveGroup:
+    def _get_group(self, group_index: Optional[int] = None, group_label: Optional[str] = None):
         assert group_index is not None or group_label is not None, 'Specify either group_index or label'
         groups = self._get_groups()
 
@@ -287,7 +286,7 @@ class ZwavePlugin(SwitchPlugin):
         assert groups, 'No such group label: {}'.format(group_label)
         return groups[0]
 
-    def _get_scene(self, scene_id: Optional[int] = None, scene_label: Optional[str] = None) -> ZWaveScene:
+    def _get_scene(self, scene_id: Optional[int] = None, scene_label: Optional[str] = None):
         assert scene_id is not None or scene_label is not None, 'Specify either scene_id or label'
         scenes = self._get_backend().network.get_scenes()
 
@@ -453,8 +452,7 @@ class ZwavePlugin(SwitchPlugin):
         self._get_network().test(count)
 
     def _get_value(self, value_id: Optional[int] = None, id_on_network: Optional[str] = None,
-                   node_id: Optional[int] = None, node_name: Optional[str] = None, value_label: Optional[str] = None) \
-            -> ZWaveValue:
+                   node_id: Optional[int] = None, node_name: Optional[str] = None, value_label: Optional[str] = None):
         assert (value_id is not None or id_on_network is not None) or \
                ((node_id is not None or node_name is not None) and value_label is not None), \
                'Specify either value_id, id_on_network, or [node_id/node_name, value_label]'
@@ -504,6 +502,7 @@ class ZwavePlugin(SwitchPlugin):
         :param node_id: Select value by [node_id/node_name, value_label]
         :param node_name: Select value by [node_id/node_name, value_label]
         """
+        from openzwave.node import ZWaveNode
         value = self._get_value(value_id=value_id, id_on_network=id_on_network,
                                 node_id=node_id, node_name=node_name, value_label=value_label)
         new_val = value.check_data(data)
@@ -988,7 +987,7 @@ class ZwavePlugin(SwitchPlugin):
     @action
     def off(self, device: str, *args, **kwargs):
         """
-        Turn on a switch on a device.
+        Turn off a switch on a device.
 
         :param device: ``id_on_network`` of the value to be switched off.
         """
